
/**
 *	XDataGrid Component
 *	
 *	Copyright (C) 2004  Kamran Zafar
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public License
 *	as published by the Free Software Foundation; either version 2
 *	of the License, or (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package xeus.db.datagrid;

import java.util.Vector;
import java.sql.*;
import java.io.*;

import org.xml.sax.SAXException;

import xeus.db.datagrid.xml.io.*;


public class XDataSet {
    private Vector models;
    private String id="";
    
    public XDataSet() {
        models=new Vector();
        
    }
    
    public XDataSet(String id) {
        this();
        
        this.id=id;
    }
    
    public static XDataSet createXDataSet(String xmlFile) throws IOException 
    {
        XDataSetXMLHandler handler = new XDataSetXMLHandler();
        
        try
        {
            handler.read(xmlFile);
        }catch(SAXException e)
        {
            e.printStackTrace();
        }
        
        return handler.getXDataSet();
    }
    
    public void addTable(ResultSet rs) throws SQLException {
        XDataGridTableModel model=new XDataGridTableModel();
        model.setResultSet(rs);
        
        models.add(model);
    }
    
    public void addTable(Vector rows,Vector columns) {
        XDataGridTableModel model=new XDataGridTableModel();
        model.setData(rows,columns);
        
        models.add(model);
    }
    
    public void addTable(Object rows[],Object columns[]) {
        addTable(toVector(rows),toVector(columns));
    }
    
    public void addTable(XDataGridTableModel model) {
        models.add(model);
    }
    
    public XDataGridTableModel getModel(int index) {
        return (XDataGridTableModel) models.elementAt(index);
    }
    
    public Vector getModels()
    {
        return models;
    }
    
    public int getTableCount() {
        return models.size();
    }
    
    public void setID(String id) {
        this.id=id;
    }
    
    public String getID()
    {
        return id;
    }
    
    public Vector toVector(Object obj[])
    {
        Vector v=new Vector();

        for(int i=0;i<obj.length;i++)
            v.add(obj[i]);
        
        return v;
    }
    
    public void writeXML(String fileName) throws IOException {
        XDataGridXMLWriter writer=new XDataGridXMLWriter(fileName);
        writer.write(this);
    }
}
